HttpError class

Represents a response Error.

Inheritance
Mixed-in types

Constructors

HttpError(String url, String requestedURL, int status, String message, Object? error)

Properties

error → Object?
The actual error thrown by the client.
final
hashCode → int
The hash code for this object.
no setterinherited
hasMessage → bool
If has the field message
no setter
httpStatus → HttpStatus
final
isError → bool
Returns true if status represents any kind of error.
no setterinherited
isNotOK → bool
Returns true if ![isOK]
no setterinherited
isOAuthAuthorizationError → bool
If is an OAuth Authorization Error. Only if response contains a JSON with matching entries and status is: 0, 400 or 401.
no setter
isOK → bool
Returns true if is a successful status.
no setterinherited
isStatusAccessError → bool
Returns true if is a Access Error status: 405..418 OR IN 400, 403, 431, 451.
no setterinherited
isStatusError → bool
Returns true if any error happens: isStatusNetworkError || isStatusServerError || isStatusAccessError
no setterinherited
isStatusForbidden → bool
Returns true if is 403 status (Forbidden).
no setterinherited
isStatusNetworkError → bool
Returns true if any network error happens.
no setterinherited
isStatusNotFound → bool
Returns true if is 404 status (Not Found).
no setterinherited
isStatusRedirect → bool
Returns true if is 300-303 or 307-308 status (Redirect).
no setterinherited
isStatusServerError → bool
Returns true if is a server error status: from range 500 to 599.
no setterinherited
isStatusSuccessful → bool
Returns true if is a successful status: from range 200 to 299.
no setterinherited
isStatusUnauthenticated → bool
Returns true if is 401 status (Unauthenticated).
no setterinherited
message → String
The error message, for better understanding than error.
final
requestedURL → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited
status → int
no setterinherited
url → String
no setterinherited

Methods

isStatus(int status) → bool
Returns true if this status is equals parameter status.
inherited
isStatusInList(List<int> statusList) → bool
Returns true if this status is in statusList.
inherited
isStatusInRange(int statusInit, int statusEnd) → bool
Returns true if this status is in range of parameters statusInit and statusEnd.
inherited
matchesAnyJSONEntry(String key, List<String> values, bool text) → bool
matchesJSONEntry(String key, String value, bool text) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited